
# Slot: subject




URI: [biolink:environment_to_phenotypic_feature_association_subject](https://w3id.org/biolink/vocab/environment_to_phenotypic_feature_association_subject)

## Domain and Range

[EnvironmentToPhenotypicFeatureAssociation](EnvironmentToPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [Environment](Environment.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [EnvironmentToPhenotypicFeatureAssociation](EnvironmentToPhenotypicFeatureAssociation.md)
